@@ -29,12 +29,19 @@ function(model,
         pred <- make_data_frame(out, fitted = tmp, se.fitted = rep(NA_real_, length(tmp)))
     }
     
-    # obs-x-(ncol(data)+2) data frame
-    structure(pred,
-              class = c("prediction", "data.frame"), 
-              row.names = seq_len(nrow(pred)),
+    # variance(s) of average predictions
+    vc <- NA_real_
+    
+    # output
+    structure(pred, 
+              class = c("prediction", "data.frame"),
               at = if (is.null(at)) at else at_specification,
-              model.class = class(model),
-              type = NA_character_)
+              type = NA_character_,
+              call = if ("call" %in% names(model)) model[["call"]] else NULL,
+              model_class = class(model),
+              row.names = seq_len(nrow(pred)),
+              vcov = vc,
+              jacobian = NULL,
+              weighted = FALSE)
 }
 
